# Exhaustive Search with Bayesian Model Averaging (ExhBMA)

# Installation
```
pip install exhbma
```

# Documentation
User documentation is available [here](https://exhbma.readthedocs.io).
You can try sample notebooks in the [tutorials](/tutorials) directory.

# Reference paper
If you use this package in your research, please cite the following paper where the package was originally introduced: ["Data integration for multiple alkali metals in predicting coordination energies based on Bayesian inference"](https://doi.org/10.1080/27660400.2022.2108353).

BibTeX entry:
```
@article{obinata2022data,
  title={Data integration for multiple alkali metals in predicting coordination energies based on Bayesian inference},
  author={Obinata, Koki and Nakayama, Tomofumi and Ishikawa, Atsushi and Sodeyama, Keitaro and Nagata, Kenji and Igarashi, Yasuhiko and Okada, Masato},
  journal={Science and Technology of Advanced Materials: Methods},
  volume={2},
  number={1},
  pages={355--364},
  year={2022},
  publisher={Taylor \& Francis}
}
```
